"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.SequelizeTypescriptMigration = exports.MigratorDir = void 0;
const fs_1 = require("fs");
const js_beautify_1 = __importDefault(require("js-beautify"));
const getDiffActionsFromTables_1 = __importStar(require("./utils/getDiffActionsFromTables"));
const getLastMigrationState_1 = require("./utils/getLastMigrationState");
const getMigration_1 = __importDefault(require("./utils/getMigration"));
const getTablesFromModels_1 = __importDefault(require("./utils/getTablesFromModels"));
const writeMigration_1 = __importDefault(require("./utils/writeMigration"));
const sqlMigration_1 = __importDefault(require("./utils/sqlMigration"));
const path_1 = __importDefault(require("path"));
const initMigration_1 = __importStar(require("./utils/initMigration"));
const getMigrator_1 = __importDefault(require("./utils/getMigrator"));
var MigratorDir;
(function (MigratorDir) {
    MigratorDir["UP"] = "up";
    MigratorDir["DOWN"] = "down";
})(MigratorDir = exports.MigratorDir || (exports.MigratorDir = {}));
class SequelizeTypescriptMigration {
}
exports.SequelizeTypescriptMigration = SequelizeTypescriptMigration;
_a = SequelizeTypescriptMigration;
/**
 * generates migration file including up, down code
 * after this, run 'npx sequelize-cli db:migrate'.
 * @param sequelize sequelize-typescript instance
 * @param options options
 */
SequelizeTypescriptMigration.makeMigration = async (sequelize, options) => {
    options.preview = options.preview || false;
    if (!(0, fs_1.existsSync)(options.outDir))
        return Promise.reject(new Error(`${options.outDir} not exists. check path and if you did 'npx sequelize init' you must use path used in sequelize migration path`));
    await sequelize.authenticate();
    const models = sequelize.models;
    const lastMigrationState = await (0, getLastMigrationState_1.getLastMigrationState)(sequelize);
    const lastMigrationVersion = await (0, getLastMigrationState_1.getLastMigrationVersion)(sequelize);
    const previousState = {
        revision: lastMigrationVersion ?? 0,
        tables: lastMigrationState?.tables ?? {},
    };
    const currentState = {
        revision: (previousState.revision || 0) + 1,
        tables: (0, getTablesFromModels_1.default)(sequelize, models, options),
    };
    await SequelizeTypescriptMigration.initMigration(sequelize, currentState, options);
    let info;
    if (options.sync) {
        const upActions = (0, getDiffActionsFromTables_1.default)(previousState.tables, currentState.tables, getDiffActionsFromTables_1.Direction.Up);
        const downActions = (0, getDiffActionsFromTables_1.default)(currentState.tables, previousState.tables, getDiffActionsFromTables_1.Direction.Down);
        const migration = (0, getMigration_1.default)(upActions);
        const tmp = (0, getMigration_1.default)(downActions);
        migration.commandsDown = tmp.commandsUp;
        //create table sync migration
        if (migration.commandsUp.length === 0)
            return Promise.resolve({ msg: 'success: no changes found' });
        // log
        migration.consoleOut.forEach((v) => {
            console.log(`[Actions] ${v}`);
        });
        if (options.preview) {
            console.log('Migration result:');
            console.log((0, js_beautify_1.default)(`[ \n${migration.commandsUp.join(', \n')} \n];\n`));
            console.log('Undo commands:');
            console.log((0, js_beautify_1.default)(`[ \n${migration.commandsDown.join(', \n')} \n];\n`));
            return Promise.resolve({ msg: 'success without save' });
        }
        info = await (0, writeMigration_1.default)(currentState, migration, options);
    }
    else {
        //create empty migration for custom migration
        info = await (0, sqlMigration_1.default)(currentState, options);
    }
    console.log(`New migration to revision ${currentState.revision} has been saved to file '${info.filename}'`);
    try {
        console.log(`Use sequelize CLI:
npx sequelize db:migrate --to ${info.revisionNumber}-${info.info.name}.js ${`--migrations-path=${options.outDir}`} `);
        return await Promise.resolve({ msg: 'success' });
    }
    catch (err) {
        if (options.debug)
            console.error(err);
    }
    return Promise.resolve({ msg: 'success anyway...' });
};
/**
 * @param sequelize sequelize-typescript instance
 * @param options options
 */
SequelizeTypescriptMigration.initMigration = async (sequelize, currentState, options) => {
    if ((0, fs_1.existsSync)(path_1.default.join(options.outDir, initMigration_1.FILE_NAME))) {
        return;
    }
    const queryInterface = sequelize.getQueryInterface();
    const info = await (0, initMigration_1.default)(currentState, options);
    console.log(`Initial migration to revision ${currentState.revision} has been saved to file '${info.filename}'`);
    // save current state, Ugly hack, see https://github.com/sequelize/sequelize/issues/8310
    const rows = [
        {
            revision: currentState.revision,
            name: info.info.name,
            state: JSON.stringify(currentState),
        },
    ];
    currentState.revision = currentState.revision + 1;
};
SequelizeTypescriptMigration.migrate = async (sequelize, options) => {
    const umzug = (0, getMigrator_1.default)(sequelize, options.path);
    return MigratorDir.UP === options.dir ? umzug.up(options.to) : umzug.down(options.to);
};
//# sourceMappingURL=index.js.map