"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLastMigrationVersion = exports.getLastMigrationState = void 0;
const sequelize_1 = require("sequelize");
async function getLastMigrationState(sequelize) {
    try {
        const [lastMigration] = await sequelize.query(`SELECT state FROM "SequelizeMigrationsMeta" ORDER BY revision desc`, { type: sequelize_1.QueryTypes.SELECT });
        if (lastMigration)
            return typeof lastMigration.state === "string"
                ? JSON.parse(lastMigration.state)
                : lastMigration.state;
    }
    catch (error) {
        //SequelizeMigrationsMeta table does not exist
    }
}
exports.getLastMigrationState = getLastMigrationState;
async function getLastMigrationVersion(sequelize) {
    try {
        const [lastExecutedMigration] = await sequelize.query('SELECT name FROM "SequelizeMeta" ORDER BY name desc limit 1', { type: sequelize_1.QueryTypes.SELECT });
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        const lastRevision = lastExecutedMigration !== undefined
            ? parseInt(lastExecutedMigration.name.split("-")[0])
            : 0;
        return lastRevision;
    }
    catch (error) {
        //SequelizeMigrationsMeta table does not exist
    }
}
exports.getLastMigrationVersion = getLastMigrationVersion;
//# sourceMappingURL=getLastMigrationState.js.map