"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MIGRATION_NAME = exports.FILE_NAME = void 0;
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const removeCurrentRevisionMigrations_1 = __importDefault(require("./removeCurrentRevisionMigrations"));
exports.FILE_NAME = '00000001-init.js';
exports.MIGRATION_NAME = 'init';
async function initMigration(currentState, options) {
    await (0, removeCurrentRevisionMigrations_1.default)(currentState.revision, options.outDir, options);
    const name = exports.MIGRATION_NAME;
    const comment = options.comment || "";
    let myState = JSON.stringify(currentState);
    const searchRegExp = /'/g;
    const replaceWith = "\\'";
    myState = myState.replace(searchRegExp, replaceWith);
    const info = {
        revision: currentState.revision,
        name,
        created: new Date(),
        comment,
    };
    const template = `'use strict';

  const Sequelize = require('sequelize');
  
  /**
   * Actions summary:
   *
   * Initialize Migration Metadata 
   *
   **/
  
  const info = {
      "revision": 1,
      "name": "tableSync",
      "created": "2024-04-11T19:34:11.031Z",
      "comment": ""
  };
  
  const migrationCommands = [
      {
          fn: "dropTable",
          params: ["SequelizeMeta"]
      },
      {
          fn: "createTable",
          params: [
              "SequelizeMeta",
              {
                  "name": {
                      "allowNull": false,
                      "primaryKey": true,
                      "type": Sequelize.STRING
                  },
                  "createdAt": {
                      "allowNull": false,
                      "type": Sequelize.DATE,
                      "defaultValue": Sequelize.fn('now')
                  },
                  "updatedAt": {
                      "allowNull": false,
                      "type": Sequelize.DATE,
                      "defaultValue": Sequelize.fn('now')
                  }
              },
              {}
          ]
      },
  
      {
          fn: "createTable",
          params: [
              "SequelizeMigrationsMeta",
              {
                  "revision": {
                      "primaryKey": true,
                      "type": Sequelize.INTEGER
                  },
                  "name": {
                      "allowNull": false,
                      "type": Sequelize.STRING
                  },
                  "state": {
                      "allowNull": false,
                      "type": Sequelize.JSON
                  },
                  "createdAt": {
                      "allowNull": false,
                      "type": Sequelize.DATE,
                      "defaultValue": Sequelize.fn('now')
                  },
                  "updatedAt": {
                      "allowNull": false,
                      "type": Sequelize.DATE,
                      "defaultValue": Sequelize.fn('now')
                  }
              },
              {}
          ]
      },
      {
          fn: "bulkDelete",
          params: [
              "SequelizeMigrationsMeta",
              [{
                  revision: info.revision
              }],
              {}
          ]
      },
      {
          fn: "bulkInsert",
          params: [
              "SequelizeMigrationsMeta",
              [{
                  revision: info.revision,
                  name: info.name,
                  state: '{"revision":1,"tables":{}}'
              }],
              {}
          ]
      },
  ];
  
  const rollbackCommands = [
  
      {
          fn: "bulkDelete",
          params: [
              "SequelizeMigrationsMeta",
              [{
                  revision: info.revision,
              }],
              {}
          ]
      },
  ];
  
  module.exports = {
    async up (queryInterface, Sequelize) {
      let index = 0;
      while (index < migrationCommands.length) {
          let command = migrationCommands[index];
          console.log("[#"+index+"] execute: " + command.fn);
          index++;
          await queryInterface[command.fn].apply(queryInterface, command.params);
      }
    },
    async down (queryInterface, Sequelize) {
      let index = 0;
      while (index < rollbackCommands.length) {
          let command = rollbackCommands[index];
          console.log("[#"+index+"] execute: " + command.fn);
          index++;
          await queryInterface[command.fn].apply(queryInterface, command.params);
      }
    },
    info
  };   
`;
    const revisionNumber = currentState.revision.toString().padStart(8, "0");
    const filename = path.join(options.outDir, `${revisionNumber + (`-${name.replace(/[\s-]/g, "_")}`)}.js`);
    fs.writeFileSync(filename, template);
    return { filename, info, revisionNumber };
}
exports.default = initMigration;
//# sourceMappingURL=initMigration.js.map